# MessageEndpointSpec

The configurable part of a message endpoint
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**endpoint_type** | [**MessageEndpointType**](MessageEndpointType.md) |  | [optional] 
**nickname** | **str** | User-supplied name (e.g. My-Yubikey, don&#39;s laptop) | [optional] 
**address** | **str** | Type-specific address info (e.g. phone num, push-context json, ...) | [optional] 
**enabled** | **bool** | The status of the message endpoint, &#x60;true&#x60; when the endpoint is enabled, and &#x60;false&#x60; when the endpoint is disabled. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


